BetterThemeData class

Annotations

Constructors

BetterThemeData({Color primaryColor = Colors.blue, EdgeInsets getFrameMargin() = _defaultGetFrameMargin, String backText = "Back", String doneText = "Done", String cancelText = "Cancel"})
const

Properties

backText String
final
cancelText String
final
doneText String
final
getFrameMargin EdgeInsets Function()
final
hashCode int
The hash code for this object.
no setteroverride
primaryColor Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Color? primaryColor, EdgeInsets getFrameMargin()?}) BetterThemeData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override